#include "install.h"

#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

extern FILE *flog;
extern char *log;

static int getdrivername(char *driver);
static int getaddresses(struct networkparams *p);

int networkmenu(struct networkparams *p)
{
	int done;
	int rc;
	char commandstring[STRING_SIZE];

	done = 0;
	while (!done)
	{
		rc = getdrivername(p->modulename);
		if (rc != 1)
			return 0;
		
		snprintf(commandstring, STRING_SIZE, "/sbin/modprobe %s", p->modulename);
		if (!(mysystem(commandstring)))
			done = 1;
		else
			errorbox("Module failed to load.");
	}

	rc = getaddresses(p);
	if (rc != 1)
		return 0;

	snprintf(commandstring, STRING_SIZE,
		"/cdrom/bin/ifconfig eth0 %s netmask %s up", p->address, p->netmask);
	if (!(mysystem(commandstring)))
		done = 1;
	else
	{
		errorbox("Interface failed to come up.");
		return 0;
	}
			
	return 1;
}
			

static int getdrivername(char *driver)
{
	char *values[] = {	NULL, NULL };	/* pointers for the values. */
	struct newtWinEntry entries[] =
		{ { "", &values[0], 0,}, { NULL, NULL, 0 } };
	int rc;
	
	rc = newtWinEntries(TITLE, "Enter the driver and optional paramateres " \
		"for the network card.  TEMPORARY!", 50, 5, 5, 20, entries, "OK", "Cancel", NULL);
		
	strncpy(driver, values[0], STRING_SIZE);
	
	return rc;
}

static int getaddresses(struct networkparams *p)
{
	char *values[] = {	NULL, NULL, NULL, NULL};	/* pointers for the values. */
	struct newtWinEntry entries[] =
	{ 
		{ "IP address", &values[0], 0, },
		{ "Network address", &values[1], 0 },
		{ "Network mask", &values[2], 0, }, 
		{ NULL, NULL, 0 }
	};
	int done;
	int rc;
	int c;
	char message[STRING_SIZE];

	do
	{
		done = 1;
	
		rc = newtWinEntries(TITLE, "Enter the IP address information", 50, 5, 5,
			18, entries, "OK", "Cancel", NULL);

		if (rc != 2)
		{
			strcpy(message, "The following fields are invalid:\n\n");
			if (inet_addr(values[0]) == INADDR_NONE)
			{
				strcat(message, "IP address\n");
				done = 0;
			}
			if (inet_addr(values[1]) == INADDR_NONE )
			{
				strcat(message, "Network address\n");
				done = 0;
			}

			if (inet_addr(values[2]) == INADDR_NONE)
			{
				strcat(message, "Network mask\n");
				done = 0;
			}

			if (!done)
				errorbox(message);
		}	
	}
	while (!done);

	strncpy(p->address, values[0], STRING_SIZE);
	strncpy(p->netaddress, values[1], STRING_SIZE);
	strncpy(p->netmask, values[2], STRING_SIZE);
	
	for (c = 0; c < 3; c++)
	{
		if (values[c]) free(values[c]);
	}
	
	return rc;
}
	
